@@ -4,10 +4,12 @@ from contextlib import asynccontextmanager
 from typing import AsyncGenerator, Coroutine, List, Sequence, TypeVar
 
 import httpx
+import nest_asyncio
+
+nest_asyncio.apply()
 
 DEFAULT_BASE_URL = "https://api.pngme.com/beta"
 
-
 T = TypeVar("T")
 
 
@@ -22,11 +24,11 @@ def with_concurrency_limit(
     """
     semaphore = asyncio.Semaphore(concurrency)
 
-    async def with_concurrency_limit(coroutine: Coroutine[None, None, T]) -> T:
+    async def _with_concurrency_limit(coroutine: Coroutine[None, None, T]) -> T:
         async with semaphore:
             return await coroutine
 
-    return [with_concurrency_limit(coroutine) for coroutine in coroutines]
+    return [_with_concurrency_limit(coroutine) for coroutine in coroutines]
 
 
 class BaseClient(ABC):
